@@ -5,7 +5,7 @@ Fits is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -28,6 +28,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include <stdlib.h>
 
+#include <gnuastro/wcs.h>
 #include <gnuastro/fits.h>
 #include <gnuastro-internal/timing.h>
 
@@ -92,7 +93,7 @@ keywords_rename_keys(struct fitsparams *p, fitsfile **fptr, int *r)
       str=gal_list_str_pop(&p->rename);
 
       /* Take a copy of the input string for error reporting, because
-         `strtok' will write into the array. */
+         'strtok' will write into the array. */
       gal_checkset_allocate_copy(str, &copy);
 
       /* Tokenize the input. */
@@ -101,18 +102,18 @@ keywords_rename_keys(struct fitsparams *p, fitsfile **fptr, int *r)
 
       /* Make sure both elements were read. */
       if(from==NULL || to==NULL)
-        error(EXIT_FAILURE, 0, "`%s' could not be tokenized in order to "
+        error(EXIT_FAILURE, 0, "'%s' could not be tokenized in order to "
               "complete rename. There should be a space character "
               "or a comma (,) between the two keyword names. If you have "
               "used the space character, be sure to enclose the value to "
-              "the `--rename' option in double quotation marks", copy);
+              "the '--rename' option in double quotation marks", copy);
 
       /* Rename the keyword */
       fits_modify_name(*fptr, from, to, &status);
       if(status) *r=fits_has_error(p, FITS_ACTION_RENAME, from, status);
       status=0;
 
-      /* Clean up the user's input string. Note that `strtok' just changes
+      /* Clean up the user's input string. Note that 'strtok' just changes
          characters within the allocated string, no extra allocation is
          done. */
       free(str);
@@ -140,7 +141,7 @@ keywords_write_set_value(struct fitsparams *p, fitsfile **fptr,
         return 1;
       else
         {
-          /* Calculate and write the `CHECKSUM' and `DATASUM' keywords. */
+          /* Calculate and write the 'CHECKSUM' and 'DATASUM' keywords. */
           if( fits_write_chksum(*fptr, &status) )
             gal_fits_io_error(status, NULL);
 
@@ -161,7 +162,7 @@ keywords_write_set_value(struct fitsparams *p, fitsfile **fptr,
     }
   else
     error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s to "
-          "fix the problem. The `keyname' value `%s' is not "
+          "fix the problem. The 'keyname' value '%s' is not "
           "recognized as one with no value", __func__,
           PACKAGE_BUGREPORT, keyll->keyname);
 
@@ -236,9 +237,9 @@ keywords_write_update(struct fitsparams *p, fitsfile **fptr,
                 gal_fits_io_error(status, NULL);
             }
           else
-            error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at `%s' so "
+            error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at '%s' so "
                   "we can fix this problem. The value %d is not valid for "
-                  "`u1w2'", __func__, PACKAGE_BUGREPORT, u1w2);
+                  "'u1w2'", __func__, PACKAGE_BUGREPORT, u1w2);
 
           /* Add the unit (if one was given). */
           if(keyll->unit
@@ -314,7 +315,7 @@ keywords_verify(struct fitsparams *p, fitsfile **fptr)
            "Checking integrity of %s (hdu %s)\n"
            "%s"
            "--------\n"
-           "Basic info (remove all extra info with `--quiet'):\n"
+           "Basic info (remove all extra info with '--quiet'):\n"
            "    - DATASUM: verifies only the data (not keywords).\n"
            "    - CHECKSUM: verifies data and keywords.\n"
            "They can be added-to/updated-in an extension/HDU with:\n"
@@ -345,13 +346,13 @@ keywords_copykeys(struct fitsparams *p, char *inkeys, size_t numinkeys)
   long initial;
   fitsfile *fptr;
 
-  /* Initial sanity check. Since `numinkeys' includes `END' (counting from
+  /* Initial sanity check. Since 'numinkeys' includes 'END' (counting from
      1, as we do here), the first keyword must not be larger OR EQUAL to
-     `numinkeys'. */
+     'numinkeys'. */
   if(p->copykeysrange[0]>=numinkeys)
     error(EXIT_FAILURE, 0, "%s (hdu %s): first keyword number give to "
-          "`--copykeys' (%ld) is larger than the number of keywords in this "
-          "header (%zu, including the `END' keyword)", p->filename, p->cp.hdu,
+          "'--copykeys' (%ld) is larger than the number of keywords in this "
+          "header (%zu, including the 'END' keyword)", p->filename, p->cp.hdu,
           p->copykeysrange[0], numinkeys);
 
   /* If the user wanted to count from the end (by giving a negative value),
@@ -365,7 +366,7 @@ keywords_copykeys(struct fitsparams *p, char *inkeys, size_t numinkeys)
       /* Sanity check. */
       if(p->copykeysrange[0]>=p->copykeysrange[1])
         error(EXIT_FAILURE, 0, "%s (hdu %s): the last keyword given to "
-              "`--copykeys' (%ld, or %ld after counting from the bottom) "
+              "'--copykeys' (%ld, or %ld after counting from the bottom) "
               "is earlier than the first (%ld)", p->filename, p->cp.hdu,
               initial, p->copykeysrange[1], p->copykeysrange[0]);
     }
@@ -373,8 +374,8 @@ keywords_copykeys(struct fitsparams *p, char *inkeys, size_t numinkeys)
   /* Final sanity check (on range limit). */
   if(p->copykeysrange[1]>=numinkeys)
     error(EXIT_FAILURE, 0, "%s (hdu %s): second keyword number give to "
-          "`--copykeys' (%ld) is larger than the number of keywords in this "
-          "header (%zu, including the `END' keyword)", p->filename, p->cp.hdu,
+          "'--copykeys' (%ld) is larger than the number of keywords in this "
+          "header (%zu, including the 'END' keyword)", p->filename, p->cp.hdu,
           p->copykeysrange[1], numinkeys);
 
 
@@ -413,24 +414,120 @@ keywords_date_to_seconds(struct fitsparams *p, fitsfile *fptr)
   /* Return the number of seconds (and subseconds) that it corresponds
      to. */
   seconds=gal_fits_key_date_to_seconds(fitsdate, &subsecstr, &subsec);
+  if(seconds==GAL_BLANK_SIZE_T)
+    error(EXIT_FAILURE, 0, "the time string couldn't be interpretted");
 
   /* Print the result (for the sub-seconds, print everything after the */
   if( !p->cp.quiet )
     {
-      printf("%s (hdu %s), key `%s': %s\n", p->filename, p->cp.hdu,
+      printf("%s (hdu %s), key '%s': %s\n", p->filename, p->cp.hdu,
              p->datetosec, fitsdate);
       printf("Seconds since 1970/01/01 (00:00:00): %zu%s\n\n", seconds,
-             subsecstr);
-      printf("(To suppress verbose output, run with `-q')\n");
+             subsecstr?subsecstr:"");
+      printf("(To suppress verbose output, run with '-q')\n");
     }
   else
-    printf("%zu%s\n", seconds, subsecstr);
+    printf("%zu%s\n", seconds, subsecstr?subsecstr:"");
+
+  /* Clean up. */
+  if(subsecstr) free(subsecstr);
 }
 
 
 
 
 
+static void
+keywords_distortion_wcs(struct fitsparams *p)
+{
+  int nwcs;
+  size_t ndim, *insize;
+  char *suffix, *output;
+  gal_data_t *data=NULL;
+  struct wcsprm *inwcs, *outwcs;
+  size_t *dsize, defaultsize[2]={2000,2000};
+
+  /* If the extension has any data, read it, otherwise just make an empty
+     array. */
+  if(gal_fits_hdu_format(p->filename, p->cp.hdu)==IMAGE_HDU)
+    {
+      /* Read the size of the dataset (we don't need the actual size!). */
+      insize=gal_fits_img_info_dim(p->filename, p->cp.hdu, &ndim);
+      free(insize);
+
+      /* If the number of dimensions is two, then read the dataset,
+         otherwise, ignore it. */
+      if(ndim==2)
+        data=gal_fits_img_read(p->filename, p->cp.hdu, p->cp.minmapsize,
+                               p->cp.quietmmap);
+    }
+
+  /* Read the input's WCS and make sure one exists. */
+  inwcs=gal_wcs_read(p->filename, p->cp.hdu, 0, 0, &nwcs);
+  if(inwcs==NULL)
+    error(EXIT_FAILURE, 0, "%s (hdu %s): doesn't have any WCS structure "
+          "for converting its distortion",
+          p->filename, p->cp.hdu);
+
+  /* In case there is no dataset and the conversion is between TPV to SIP,
+     we need to set a default size and use that for the conversion, but we
+     also need to warn the user. */
+  if(data==NULL)
+    {
+      if( !p->cp.quiet
+          && gal_wcs_distortion_identify(inwcs)==GAL_WCS_DISTORTION_TPV
+          && p->distortionid==GAL_WCS_DISTORTION_SIP )
+        error(0, 0, "no data associated with WCS for distortion "
+              "conversion.\n\n"
+              "The requested conversion can't be done analytically, so a "
+              "solution has to be found by fitting the parameters over a "
+              "grid of pixels. We will use a default grid of %zux%zu pixels "
+              "and will proceed with the conversion. But it would be more "
+              "accurate if it is the size of the image that this WCS is "
+              "associated with",
+              defaultsize[1], defaultsize[0]);
+      dsize=defaultsize;
+    }
+  else dsize=data->dsize;
+
+  /* Do the conversion. */
+  outwcs=gal_wcs_distortion_convert(inwcs, p->distortionid, dsize);
+
+  /* Set the output filename. */
+  if(p->cp.output)
+    output=p->cp.output;
+  else
+    {
+      if( asprintf(&suffix, "-%s.fits", p->wcsdistortion)<0 )
+        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+      output=gal_checkset_automatic_output(&p->cp, p->filename, suffix);
+    }
+  gal_checkset_writable_remove(output, 0, p->cp.dontdelete);
+
+  /* Write the output file. */
+  if(data)
+    {
+      /* Add the output WCS to the dataset and write it. */
+      data->wcs=outwcs;
+      gal_fits_img_write(data, output, NULL, PROGRAM_NAME);
+
+      /* Clean up, but remove the pointer first (so it doesn't free it
+         here). */
+      data->wcs=NULL;
+      gal_data_free(data);
+    }
+  else
+    gal_wcs_write(outwcs, output, p->wcsdistortion, NULL, PROGRAM_NAME);
+
+  /* Clean up. */
+  wcsfree(inwcs);
+  wcsfree(outwcs);
+  if(output!=p->cp.output) free(output);
+}
+
+
+
+
 
 
 
@@ -451,12 +548,12 @@ keywords_date_to_seconds(struct fitsparams *p, fitsfile *fptr)
 /***********************************************************************/
 /* NOTE ON CALLING keywords_open FOR EACH OPERATION:
 
-   `keywords_open' is being called individually for each separate operation
+   'keywords_open' is being called individually for each separate operation
    because the necessary permissions differ: when the user only wants to
    read keywords, they don't necessarily need write permissions. So if they
    haven't asked for any writing/editing operation, we shouldn't open in
    write-mode. Because the user might not have the permissions to write and
-   they might not want to write. `keywords_open' will only open the file
+   they might not want to write. 'keywords_open' will only open the file
    once (if the pointer is already allocated, it won't do anything). */
 int
 keywords(struct fitsparams *p)
@@ -467,7 +564,6 @@ keywords(struct fitsparams *p)
   gal_list_str_t *tstll;
   int status=0, numinkeys;
 
-
   /* Delete the requested keywords. */
   if(p->delete)
     {
@@ -597,7 +693,7 @@ keywords(struct fitsparams *p)
 
 
   /* Close the FITS file */
-  if(fits_close_file(fptr, &status))
+  if(fptr && fits_close_file(fptr, &status))
     gal_fits_io_error(status, NULL);
 
 
@@ -608,6 +704,10 @@ keywords(struct fitsparams *p)
       free(inkeys);
     }
 
+  /* Convert the input's distortion to the desired output distortion. */
+  if(p->wcsdistortion)
+    keywords_distortion_wcs(p);
+
   /* Return. */
   return r;
 }
