@@ -5,7 +5,7 @@ Statistics is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2019, Free Software Foundation, Inc.
+Copyright (C) 2015-2020, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -106,8 +106,8 @@ statistics_print_one_row(struct statisticsparams *p)
   for(tmp=p->singlevalue; tmp!=NULL; tmp=tmp->next)
     switch(tmp->v)
       {
-      /* Calculate respective values. Checking with `if(num==NULL)' gives
-         compiler warnings of `this if clause does not guard ...'. So we
+      /* Calculate respective values. Checking with 'if(num==NULL)' gives
+         compiler warnings of 'this if clause does not guard ...'. So we
          are using this empty-if and else statement. */
       case UI_KEY_NUMBER:
         num = num ? num : gal_statistics_number(p->input);           break;
@@ -211,7 +211,7 @@ statistics_print_one_row(struct statisticsparams *p)
 
       /* Print the number. Note that we don't want any extra white space
          characters before or after the printed outputs. So we have defined
-         `counter' to add a single white space character before any element
+         'counter' to add a single white space character before any element
          except the first one. */
       toprint=gal_type_to_string(out->array, out->type, 0);
       printf("%s%s", counter ? " " : "", toprint);
@@ -271,11 +271,12 @@ statistics_interpolate_and_write(struct statisticsparams *p,
   if( p->interpolate
       && !(p->cp.interponlyblank && gal_blank_present(values, 1)==0) )
     {
-      interpd=gal_interpolate_close_neighbors(values, &cp->tl,
-                                              cp->interpmetric,
-                                              cp->interpnumngb,
-                                              cp->numthreads,
-                                              cp->interponlyblank, 0);
+      interpd=gal_interpolate_neighbors(values, &cp->tl,
+                                        cp->interpmetric,
+                                        cp->interpnumngb,
+                                        cp->numthreads,
+                                        cp->interponlyblank, 0,
+                                        GAL_INTERPOLATE_NEIGHBORS_FUNC_MEDIAN);
       gal_data_free(values);
       values=interpd;
     }
@@ -415,7 +416,7 @@ statistics_on_tile(struct statisticsparams *p)
                     "recognized", __func__, PACKAGE_BUGREPORT, operation->v);
             }
 
-          /* Put the output value into the `values' array and clean up. */
+          /* Put the output value into the 'values' array and clean up. */
           tmp=gal_data_copy_to_new_type_free(tmp, type);
           memcpy(gal_pointer_increment(values->array, tind++, values->type),
                  tmp->array, gal_type_sizeof(type));
@@ -503,9 +504,9 @@ print_ascii_plot(struct statisticsparams *p, gal_data_t *plot,
 
 
 
-/* Data structure that must be fed into `gal_statistics_regular_bins'.*/
+/* Data structure that must be fed into 'gal_statistics_regular_bins'.*/
 static gal_data_t *
-set_bin_range_params(struct statisticsparams *p)
+set_bin_range_params(struct statisticsparams *p, size_t dim)
 {
   size_t rsize=2;
   gal_data_t *range=NULL;
@@ -515,8 +516,21 @@ set_bin_range_params(struct statisticsparams *p)
       /* Allocate the range data structure. */
       range=gal_data_alloc(NULL, GAL_TYPE_FLOAT32, 1, &rsize, NULL, 0, -1, 1,
                            NULL, NULL, NULL);
-      ((float *)(range->array))[0]=p->greaterequal;
-      ((float *)(range->array))[1]=p->lessthan;
+      switch(dim)
+        {
+        case 1:
+          ((float *)(range->array))[0]=p->greaterequal;
+          ((float *)(range->array))[1]=p->lessthan;
+          break;
+        case 2:
+          ((float *)(range->array))[0]=p->greaterequal2;
+          ((float *)(range->array))[1]=p->lessthan2;
+          break;
+        default:
+          error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s to "
+                "address the problem. The value %zu for 'dim' isn't "
+                "recogized", __func__, PACKAGE_BUGREPORT, dim);
+        }
     }
   return range;
 }
@@ -531,7 +545,7 @@ ascii_plots(struct statisticsparams *p)
   gal_data_t *bins, *hist, *cfp=NULL, *range=NULL;
 
   /* Make the bins and the respective plot. */
-  range=set_bin_range_params(p);
+  range=set_bin_range_params(p, 1);
   bins=gal_statistics_regular_bins(p->input, range, p->numasciibins, NAN);
   hist=gal_statistics_histogram(p->input, bins, 0, 0);
   if(p->asciicfp)
@@ -587,7 +601,7 @@ write_output_table(struct statisticsparams *p, gal_data_t *table,
   use_auto_output = p->cp.output ? (p->numoutfiles>1 ? 1 : 0) : 1;
 
 
-  /* Set the `fix' and `suffix' strings. Note that `fix' is necessary in
+  /* Set the 'fix' and 'suffix' strings. Note that 'fix' is necessary in
      every case, even when no automatic output is to be used. Since it is
      used to determine the format of the output. */
   fix = ( p->cp.output
@@ -615,12 +629,13 @@ write_output_table(struct statisticsparams *p, gal_data_t *table,
   gal_list_str_add(&comments, tmp, 0);
 
   if(strcmp(fix, "fits"))  /* The intro info will be in FITS files anyway.*/
-    gal_table_comments_add_intro(&comments, PROGRAM_NAME, &p->rawtime);
+    gal_table_comments_add_intro(&comments, PROGRAM_STRING, &p->rawtime);
 
 
   /* Write the table. */
   gal_checkset_writable_remove(output, 0, p->cp.dontdelete);
-  gal_table_write(table, comments, p->cp.tableformat, output, "TABLE", 0);
+  gal_table_write(table, NULL, comments, p->cp.tableformat, output,
+                  "TABLE", 0);
 
 
   /* Write the configuration information if we have a FITS output. */
@@ -656,7 +671,7 @@ save_hist_and_or_cfp(struct statisticsparams *p)
   /* Set the bins and make the histogram, this is necessary for both the
      histogram and CFP (recall that the CFP is built from the
      histogram). */
-  range=set_bin_range_params(p);
+  range=set_bin_range_params(p, 1);
   bins=gal_statistics_regular_bins(p->input, range, p->numbins,
                                    p->onebinstart);
   hist=gal_statistics_histogram(p->input, bins, p->normalize, p->maxbinone);
@@ -665,20 +680,20 @@ save_hist_and_or_cfp(struct statisticsparams *p)
   /* Set the histogram as the next pointer of bins. This is again necessary
      in both cases: when only a histogram is requested, it is used for the
      plotting. When only a CFP is desired, it is used as input into
-     `gal_statistics_cfp'. */
+     'gal_statistics_cfp'. */
   bins->next=hist;
 
 
   /* Make the cumulative frequency plot if the user wanted it. Make the
-     CFP, note that for the CFP, `maxbinone' and `normalize' are the same:
+     CFP, note that for the CFP, 'maxbinone' and 'normalize' are the same:
      the last bin (largest value) must be one. So if any of them are given,
      then set the last argument to 1.*/
   if(p->cumulative)
     cfp=gal_statistics_cfp(p->input, bins, p->normalize || p->maxbinone);
 
 
-  /* FITS tables don't accept `uint64_t', so to be consistent, we'll conver
-     the histogram and CFP to `uint32_t'.*/
+  /* FITS tables don't accept 'uint64_t', so to be consistent, we'll conver
+     the histogram and CFP to 'uint32_t'.*/
   if(hist->type==GAL_TYPE_UINT64)
     hist=gal_data_copy_to_new_type_free(hist, GAL_TYPE_UINT32);
   if(cfp && cfp->type==GAL_TYPE_UINT64)
@@ -692,11 +707,11 @@ save_hist_and_or_cfp(struct statisticsparams *p)
 
   /* Prepare the contents. */
   if(p->histogram && p->cumulative)
-    { suf="_hist_cfp"; contents="Histogram and cumulative frequency plot"; }
+    { suf="-hist-cfp"; contents="Histogram and cumulative frequency plot"; }
   else if(p->histogram)
-    { suf="_hist";     contents="Histogram"; }
+    { suf="-hist";     contents="Histogram"; }
   else
-    { suf="_cfp";      contents="Cumulative frequency plot"; }
+    { suf="-cfp";      contents="Cumulative frequency plot"; }
 
 
   /* Set the output file name. */
@@ -710,6 +725,38 @@ save_hist_and_or_cfp(struct statisticsparams *p)
 
 
 
+static void
+histogram_2d(struct statisticsparams *p)
+{
+  char *suf, *contents;
+  gal_data_t *hist2d, *bins;
+  gal_data_t *range1, *range2;
+
+  /* Set the bins for each dimension */
+  range1=set_bin_range_params(p, 1);
+  range2=set_bin_range_params(p, 2);
+  bins=gal_statistics_regular_bins(p->input, range1, p->numbins,
+                                   p->onebinstart);
+  bins->next=gal_statistics_regular_bins(p->input->next, range2,
+                                         p->numbins2,
+                                         p->onebinstart2);
+
+  /* Build the 2D histogram. */
+  hist2d=gal_statistics_histogram2d(p->input, bins);
+
+  /* Write the output. */
+  suf="-hist2d";
+  contents="2D Histogram";
+  write_output_table(p, hist2d, suf, contents);
+
+  /* Clean up. */
+  gal_list_data_free(hist2d);
+}
+
+
+
+
+
 void
 print_mirror_hist_cfp(struct statisticsparams *p)
 {
@@ -766,7 +813,7 @@ print_mirror_hist_cfp(struct statisticsparams *p)
 /*******************************************************************/
 /**************           Basic information          ***************/
 /*******************************************************************/
-/* To keep things in `print_basics' clean, we'll define the input data
+/* To keep things in 'print_basics' clean, we'll define the input data
    here, then only print the values there. */
 void
 print_input_info(struct statisticsparams *p)
@@ -784,8 +831,8 @@ print_input_info(struct statisticsparams *p)
   printf("Input: %s\n", name);
 
   /* If a table was given, print the column. */
-  if(p->column) printf("Column: %s\n",
-                       p->input->name ? p->input->name : p->column);
+  if(p->columns) printf("Column: %s\n",
+                        p->input->name ? p->input->name : p->columns->v);
 
   /* Range. */
   str=NULL;
@@ -874,7 +921,7 @@ print_basics(struct statisticsparams *p)
   tmp=gal_statistics_mode(p->input, mirrdist, 1);
   d=tmp->array;
   if(d[2]>GAL_STATISTICS_MODE_GOOD_SYM)
-    {        /* Same format as `gal_data_write_to_string' */
+    {        /* Same format as 'gal_data_write_to_string' */
       printf("  %-*s %.10g\n", namewidth, "Mode:", d[0]);
       printf("  %-*s %.10g\n", namewidth, "Mode quantile:", d[1]);
     }
@@ -888,7 +935,7 @@ print_basics(struct statisticsparams *p)
   free(str);
 
   /* Print the mean and standard deviation. Same format as
-     `gal_data_write_to_string' */
+     'gal_data_write_to_string' */
   printf("  %-*s %.10g\n", namewidth, "Mean:", mean);
   printf("  %-*s %.10g\n", namewidth, "Standard deviation:", std);
 
@@ -898,7 +945,7 @@ print_basics(struct statisticsparams *p)
      range of the histogram. In that case, we want to print the histogram
      information. */
   printf("-------");
-  range=set_bin_range_params(p);
+  range=set_bin_range_params(p, 1);
   p->asciiheight = p->asciiheight ? p->asciiheight : 10;
   p->numasciibins = p->numasciibins ? p->numasciibins : 70;
   bins=gal_statistics_regular_bins(p->input, range, p->numasciibins, NAN);
@@ -1045,6 +1092,13 @@ statistics(struct statisticsparams *p)
       save_hist_and_or_cfp(p);
     }
 
+  /* 2D histogram. */
+  if(p->histogram2d)
+    {
+      print_basic_info=0;
+      histogram_2d(p);
+    }
+
   /* Print the sigma-clipped results. */
   if( p->sigmaclip )
     {
