@@ -162,6 +162,9 @@ gal_data_t *
 gal_statistics_histogram(gal_data_t *data, gal_data_t *bins,
                          int normalize, int maxhistone);
 
+gal_data_t *
+gal_statistics_histogram2d(gal_data_t *input, gal_data_t *bins);
+
 gal_data_t *
 gal_statistics_cfp(gal_data_t *data, gal_data_t *bins, int normalize);
 
@@ -177,9 +180,10 @@ gal_statistics_sigma_clip(gal_data_t *input, float multip, float param,
                           int inplace, int quiet);
 
 gal_data_t *
-gal_statistics_outlier_positive(gal_data_t *input, size_t window_size,
-                                float sigma, float sigclip_multip,
-                                float sigclip_param, int inplace, int quiet);
+gal_statistics_outlier_bydistance(int pos1_neg0, gal_data_t *input,
+                                  size_t window_size, float sigma,
+                                  float sigclip_multip, float sigclip_param,
+                                  int inplace, int quiet);
 
 gal_data_t *
 gal_statistics_outlier_flat_cfp(gal_data_t *input, size_t numprev,
