@@ -29,7 +29,10 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <wcslib/wcs.h>
 
 #include <gnuastro/data.h>
+#include <gnuastro/fits.h>
 
+/* Assumed floating point error in the WCS-related functionality. */
+#define GAL_WCS_FLTERROR 1e-12
 
 /* C++ Preparations */
 #undef __BEGIN_C_DECLS
@@ -52,6 +55,25 @@ __BEGIN_C_DECLS  /* From C++ preparations */
 
 
 
+/*************************************************************
+ **************           Constants            ***************
+ *************************************************************/
+/* Macros to identify the type of distortion for conversions. */
+enum gal_wcs_distortions
+{
+  GAL_WCS_DISTORTION_INVALID,         /* Invalid (=0 by C standard).    */
+
+  GAL_WCS_DISTORTION_TPD,             /* The TPD polynomial distortion. */
+  GAL_WCS_DISTORTION_SIP,             /* The SIP polynomial distortion. */
+  GAL_WCS_DISTORTION_TPV,             /* The TPV polynomial distortion. */
+  GAL_WCS_DISTORTION_DSS,             /* The DSS polynomial distortion. */
+  GAL_WCS_DISTORTION_WAT,             /* The WAT polynomial distortion. */
+};
+
+
+
+
+
 /*************************************************************
  ***********               Read WCS                ***********
  *************************************************************/
@@ -66,6 +88,39 @@ gal_wcs_read(char *filename, char *hdu, size_t hstartwcs,
 
 
 
+/*************************************************************
+ ***********               Write WCS               ***********
+ *************************************************************/
+void
+gal_wcs_write(struct wcsprm *wcs, char *filename,
+              char *extname, gal_fits_list_key_t *headers,
+              char *program_string);
+
+void
+gal_wcs_write_in_fitsptr(fitsfile *fptr, struct wcsprm *wcs);
+
+
+
+
+/*************************************************************
+ ***********              Distortions              ***********
+ *************************************************************/
+int
+gal_wcs_distortion_from_string(char *distortion);
+
+char *
+gal_wcs_distortion_to_string(int distortion);
+
+int
+gal_wcs_distortion_identify(struct wcsprm *wcs);
+
+struct wcsprm *
+gal_wcs_distortion_convert(struct wcsprm *inwcs,
+                           int out_distortion, size_t *fitsize);
+
+
+
+
 
 /**************************************************************/
 /**********              Utilities                 ************/
@@ -82,6 +137,9 @@ gal_wcs_on_tile(gal_data_t *tile);
 double *
 gal_wcs_warp_matrix(struct wcsprm *wcs);
 
+void
+gal_wcs_clean_errors(struct wcsprm *wcs);
+
 void
 gal_wcs_decompose_pc_cdelt(struct wcsprm *wcs);
 
